Name:		jogl
Version:	1.1.1a
Release:	13%{?dist}
Summary:	Java bindings for the OpenGL API

Group:		Development/Libraries
License:	MIT and BSD
URL:		http://jogl.dev.java.net
ExcludeArch:	%{arm}
Source0:	http://download.java.net/media/jogl/builds/archive/jsr-231-1.1.1a/jogl-1.1.1a-src.zip
Source1:	%{name}.properties
# Change include and library paths for X11R6 to match actual locations on
# Fedora systems.
Patch0:		jogl-X11R6.patch
# Fix the expected input encoding for javadoc generation.
Patch1:		jogl-encoding.patch
# Fix loading of the compiled C code at runtime.
Patch2:		jogl-defaultFedoraPath.patch

BuildRequires:	ant-antlr
BuildRequires:	java-1.7.0-openjdk-devel
BuildRequires:	jpackage-utils
BuildRequires:	mesa-libGLU-devel
BuildRequires:	libX11-devel
BuildRequires:	gtkglext-devel
BuildRequires:	libXt-devel
BuildRequires:	libXxf86vm-devel
BuildRequires:	xorg-x11-proto-devel
BuildRequires:	gluegen-source
BuildRequires:	cpptasks

Requires:	jpackage-utils
Requires:	java-headless >= 1:1.6
Requires:	gluegen

%description
The JOGL project hosts the development version of the Java Binding for
the OpenGL API (JSR-231), and is designed to provide hardware-supported 3D
graphics to applications written in Java. JOGL provides full access to the
APIs in the OpenGL 2.0 specification as well as nearly all vendor extensions,
and integrates with the AWT and Swing widget sets. It is part of a suite of
open-source technologies initiated by the Game Technology Group at
Sun Microsystems.

%package javadoc
Summary:	Javadoc for jogl
Group:		Documentation
Requires:	jpackage-utils

%description javadoc
Javadoc for jogl.

%package manual
Summary:	User manual for jogl
Group:		Documentation

%description manual
User manual for jogl

%prep
%setup -q -c

find . -name '*.jar' | xargs rm -f
find . -name '*.class' | xargs rm -f

%patch0 -b .X11R6
%patch1 -b .encoding
%patch2 -b .defaultFedoraPath
cd jogl
iconv -f iso8859-1 -t utf-8 -o README.txt.conv README.txt
touch -r README.txt README.txt.conv
mv -f README.txt.conv README.txt
cp -rdf %{_datadir}/gluegen-source/gluegen ..

%build
cd jogl/make
ant \
    -Duser.home=%{_topdir}/SOURCES \
    -Dantlr.jar=$(build-classpath antlr) \
    -Dc.compiler.debug=true \
    -Dc.compiler.optimise=speed \
    all \
    javadoc.dev.x11

%install
cd jogl

# jars
mkdir -p %{buildroot}%{_libdir}/%{name}
install -pm 0644 build/%{name}.jar %{buildroot}%{_libdir}/%{name}/%{name}.jar

# native lib
install -dm 755 %{buildroot}%{_libdir}/%{name}
install -m 744 build/obj/lib*.so \
	%{buildroot}%{_libdir}/%{name}

# javadoc
install -dm 755 %{buildroot}%{_javadocdir}/%{name}
cp -pr javadoc_jogl_dev/* %{buildroot}%{_javadocdir}/%{name}

%files
%defattr(-,root,root,-)
%doc jogl/LICENSE.txt jogl/CHANGELOG.txt jogl/COPYRIGHT.txt jogl/README.txt
%{_libdir}/%{name}/*.jar
%attr(755,root,root) %{_libdir}/%{name}/libjogl.so
%attr(755,root,root) %{_libdir}/%{name}/libjogl_awt.so

%files javadoc
%defattr(-,root,root)
%doc %{_javadocdir}/%{name} 
%doc jogl/LICENSE.txt jogl/COPYRIGHT.txt

%files manual
%defattr(-,root,root)
%doc jogl/doc/* 
%doc jogl/LICENSE.txt jogl/COPYRIGHT.txt


%changelog
* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.1a-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Tue Aug 13 2013 Jon Ciesla <limburgher@gmail.com> - 1.1.1a-12
- Switch to java-headless, BZ 1068298.

* Tue Aug 13 2013 Jon Ciesla <limburgher@gmail.com> - 1.1.1a-11
- Excludearch ARM, not supported, BZ 992636.

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.1a-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.1a-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Fri Jul 20 2012 Jon Ciesla <limburgher@gmail.com> - 1.1.1a-8
- Update java BR to fix FTBFS.

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.1a-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.1a-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Fri May 20 2011 Jon Ciesla <limb@jcomserv.net> - 1.1.1a-5
- Corrected license tag.
- Removing prebuilt jar and class files in setup.
- Added license files to subpackages.

* Mon Apr 04 2011 Jon Ciesla <limb@jcomserv.net> - 1.1.1a-4
- Added Aiden's defaultFedoraPath.

* Mon Feb 21 2011 Aidan Delaney <a.j.delaney@brighton.ac.uk> - 1.1.1a-3
- Licence change as per discussion on https://bugzilla.redhat.com/show_bug.cgi?id=572515

* Thu Aug 05 2010 Aidan Delaney <a.j.delaney@brighton.ac.uk> - 1.1.1a-2
- Added a modified version of the Debian patch from http://svn.debian.org/viewsvn/pkg-java/trunk/libjogl-java/debian/patches/defaultDebianPath.diff
- Allows jogl.jar and .so to be installed into /usr/lib{64}/jogl as per Fedora JNI packaging guidelines

* Wed Jul 28 2010 Aidan Delaney <a.j.delaney@brighton.ac.uk> - 1.1.1a-1
- Addressed issued raised by Chen Lei in BZ #572515

* Sun Apr 04 2010 Henrique Junior and Sylvestre Ledru <lspooky@fedoraproject.org> - 1.1.1-6
- Added post and postum section

* Fri Apr 02 2010 Henrique Junior and Sylvestre Ledru <lspooky@fedoraproject.org> - 1.1.1-5
- New approach on using the gluegen source, now, JOGL is "cp"ing it

* Tue Mar 09 2010 Henrique Junior and Sylvestre Ledru <lspooky@fedoraproject.org> - 1.1.1-4
- Some cleaning on .spec

* Tue Mar 09 2010 Henrique Junior and Sylvestre Ledru <lspooky@fedoraproject.org> - 1.1.1-3
- Changes to use the new gluegen-source package

* Fri Feb 26 2010 Henrique Junior and Sylvestre Ledru <lspooky@fedoraproject.org> - 1.1.1-2
- Refinements in .spec

* Sat Feb 20 2010 Henrique Junior and Sylvestre Ledru <lspooky@fedoraproject.org> - 1.1.1-1
- Initial package.
